@@ -76,6 +76,7 @@ from datalad.tests.utils_pytest import (
     with_sameas_remote,
     with_tempfile,
     with_tree,
+    xfail_buggy_annex_info,
 )
 from datalad.utils import (
     Path,
@@ -1554,6 +1555,7 @@ def test_clone_unborn_head_sub(path=None):
     eq_(managed, ds_cloned_sub.repo.is_managed_branch())
 
 
+@xfail_buggy_annex_info
 @skip_if_no_network
 @with_tempfile
 def test_gin_cloning(path=None):
