@@ -1062,11 +1062,22 @@ def known_failure_osx(func):
         return dm_func
     return func
 
+
 # ### ###
-# END known failure decorators
+# xfails - like known failures but never to be checked to pass etc.
+#   e.g. for specific versions of core tools with regressions
 # ### ###
 
 
+xfail_buggy_annex_info = pytest.mark.xfail(
+    # 10.20230127 is lower bound since bug was introduced before next 10.20230214
+    # release, and thus snapshot builds would fail. There were no release on
+    # '10.20230221' - but that is the next day after the fix
+    external_versions['cmd:annex'] and ('10.20230127' <= external_versions['cmd:annex'] < '10.20230221'),
+    reason="Regression in git-annex info. https://github.com/datalad/datalad/issues/7286"
+)
+
+
 def _get_resolved_flavors(flavors):
     #flavors_ = (['local', 'clone'] + (['local-url'] if not on_windows else [])) \
     #           if flavors == 'auto' else flavors
